Citing pydemic
===============

If you use :mod:`pydemic` in your work, please cite the following article:

    G. N. Wong, Z. J. Weiner, A. V. Tkachenko, A. Elbanna, S. Maslov,
    and N. Goldenfeld,
    "Modeling COVID-19 dynamics in Illinois under non-pharmaceutical interventions", (2020), arXiv:2006.02036 [q-bio.PE].

Here's a Bibtex entry for your convenience:

.. code-block:: latex

    @article{wong2020modeling,
        title={{Modeling COVID-19 dynamics in Illinois under non-pharmaceutical interventions}},
        author={George N. Wong and Zachary J. Weiner and Alexei V. Tkachenko
                and Ahmed Elbanna and Sergei Maslov and Nigel Goldenfeld},
        year={2020},
        eprint={2006.02036},
        archivePrefix={arXiv},
        primaryClass={q-bio.PE}
    }